/******************************************************************************
          Copyright (C) 1990, Photometrics, Ltd. All Rights Reserved
******************************************************************************/

/************* You must "#include <at200.h>" before this file. ***************/

/******************************************************************************
                     AT200 High-Level Control Structures
******************************************************************************/
typedef struct {
  ccd_descript ccd;       /* The current CCD characterization */
  unsigned at200_id:5;    /* The ID of the current AT200/M200 [0..31]
                             The I/O address of the AT200/M200 is calculated
                             from this value as: 0x200 + (at200_id * 16) */
  unsigned frame:1;       /* TRUE=Using frame transfer mode */
  unsigned open_delay:5;  /* Milliseconds to delay when opening the shutter */
  unsigned close_delay:5; /* Milliseconds to delay when closing the shutter */
  unsigned preamp_delay:7;/* Milliseconds to delay after turning the preamp on */
  unsigned speed:3;       /* Analog Speed code (see below) */
  unsigned data_bits:5;   /* Number of data bits in the A/D converter */
} cam_sys;

typedef struct {
  unsigned far * far * ram; /* Pointer to array of pointers to data segments.
                               Each entry in this array of pointers points to
                               an area of memory that will be used to hold 2K
                               pixels (4K Bytes) from the controller.
                               Calculate the number of required entries as
                               ((pixels - 1) / 2048) + 1 */
  unsigned long exposure;   /* Milliseconds to expose CCD */
  unsigned gain;            /* Gain: Zero=>1x, Non-Zero=>4x */
  unsigned mpp_mode;        /* Zero=Don't use MPP, Non-Zero=Use MPP */
  unsigned corg;            /* Columns to skip before readout */
  unsigned rorg;            /* Rows to skip before readout */
  unsigned cols;            /* Columns to readout */
  unsigned rows;            /* Rows to readout */
  unsigned cbin;            /* Column binning factor */
  unsigned rbin;            /* Row binning factor */
  unsigned clr_cnt;         /* Cycles to clear before exposure */
  unsigned row_shift;       /* Rows to shift in the shift() function */
} cam_exp;
/******************************************************************************
                              Analog Speed Codes
******************************************************************************/
#define A40KHZ    0         /* Indicates 40KHz analog card */
#define A50KHZ    1         /* Indicates 50KHz analog card */
#define A200KHZ   2         /* Indicates 200KHz analog card */
#define A500KHZ   3         /* Indicates 500KHz analog card */

/******************************************************************************
                             External Definitions
******************************************************************************/
extern char far *error_msgs[];    /* The AT200 Error Messages */

/******************************************************************************
                             Function Prototypes
******************************************************************************/
int  cam_data_waiting(void); /* TRUE=Data in FIFO */
int  cam_wait(void); /* Waits for data from the camera (no timeout!) */
int  clear(void); /* Clears the CCD by the number at the last set_exp() call */
int  continuous_clear(void); /* Starts continuous clearing of the CCD */
int  cshut(void); /* Closes the shutter */
int  expose_dark(void); /* Dark Exposure */
int  expose_light(void); /* Light Exposure */
int  oshut(void); /* Opens the shutter */
int  readis(void); /* Reads out Image and Storage arrays */
int  reads(void); /* Reads out Storage array only. Data must be shift()ed in */
int  setup(cam_sys far *config); /* Selects a CCD configuration */
int  set_exp(cam_exp far *new_readout); /* Selects readout parameters */
int  shift(void); /* Shifts image and storage by last set_exp() call */
int  trigger(void); /* Sets up to wait for external trigger */
int  ttl_read(void); /* Reads data from the TTL I/O port */
void ttl_write(int data,int mask); /* Sends data to the TTL I/O port */
