/******************************************************************************
          Copyright (C) 1990, Photometrics, Ltd. All Rights Reserved
******************************************************************************/
/******************************************************************************
                  Defines for DSP56001 Host Command Vectors.
******************************************************************************/
#define DSP_IRQA             4  /* Simulated IRQA (End of External Trigger) */
#define DSP_IRQB             5  /* Simulated IRQB (External Trigger) */
#define DSP_HALT            15  /* Stop any operation in progress. */
#define SET_PREAMP          18  /* Get the Preamp Delay from HOST (Def=100) */
#define SET_SHUTTER_OPEN    19  /* Get Shutter Open Delay from HOST (Def=10) */
#define SET_SHUTTER_CLOSE   20  /* Get Shutter Close Delay from HOST (Def=10) */
#define SET_NORMAL_EXPOSE   21  /* Select Non-MPP,Non-HWELL Exposure (Default) */
#define SET_MPP_EXPOSE      22  /* Select MPP Exposure (Def=FALSE) */
#define SET_HWELL_EXPOSE    23  /* Select HWELL Exposure(Def=FALSE) */
#define SET_MPP_CLOCK       24  /* Select MPP Parallel Clocks (Def=FALSE) */
#define SET_NORMAL_CLOCK    25  /* Select Non-MPP Parallel Clocks (Default) */
#define SET_PARALLEL_DELAY  26  /* Get CCD Parallel Delay from HOST */
#define SET_PARALLEL_STATES 27  /* Get CCD Parallel States from HOST (Def=8) */
#define LOAD_OPERATIONS     28  /* Get up to 256 OPERATIONS from HOST */
#define UNLOAD_OPERATIONS   29  /* Send the operations at Y:OPERATIONS to HOST */
#define EXECUTE             30  /* Execute the operations at Y:OPERATIONS */
/******************************************************************************
                       Defines for DSP56001 Operations.
             Operations arguments are 16 bits passed in TXH,TXM.
                       The operation is passed in TXL.
******************************************************************************/
#define OP_TERMINATE          0 /* End of Operation List */
#define OP_DO_LOOP            1 /* Do Loop (N) times (can nest 16 deep) */
#define OP_END_DO             2 /* End Do Loop */
#define OP_CLEAR_UNTIL_TRIG   3 /* Continuous Clear & Wait for External Trigger */
#define OP_WAIT_FOR_TRIG      3 /* OBSOLETE - REMOVE FROM YOUR CODE */
#define OP_EXPOSE_SCALE       4 /* Set Inner Loop for Exposure Timing to (msec) */
#define OP_EXPOSE             5 /* Wait for Exposure Timer (N) Times */
#define OP_OPEN_SHUTTER       6 /* Open the Shutter */
#define OP_CLOSE_SHUTTER      7 /* Close the Shutter */
#define OP_SELECT_I_S         8 /* Select Image and Storage */
#define OP_SELECT_S           9 /* Select Storage Only */
#define OP_PARALLEL_DIS      10 /* Parallel Discard (N) rows */
#define OP_PARALLEL_BIN      11 /* Parallel Bin (N) rows */
#define OP_SERIAL_DIS        12 /* Serial Discard (N) pixels */
#define OP_SET_SER_BIN       13 /* Set the Serial Bin Count to (N) pixels */
#define OP_SERIAL_CONV       14 /* Serial Convert & Transfer (N) times */
#define OP_SET_GAIN          15 /* Set the Gain Counter (N) */
#define OP_PREAMP_ON         16 /* Turn on the Preamp */
#define OP_PREAMP_OFF        17 /* Turn off the Preamp */
#define OP_WAIT_FOR_0        18 /* Wait for Host Flag 0 */
#define OP_WAIT_FOR_1        19 /* Wait for Host Flag 1 */
#define OP_EXPOSE_UNTIL_TRIG 20 /* Expose While Waiting for External Trigger */
#define OP_WAIT_FOR_TDI      20 /* OBSOLETE - REMOVE FROM YOUR CODE */
#define OP_DIAGNOSTIC_1      21 /* Reserved for Photometrics Use */
#define OP_EXPOSE_WHILE_TRIG 22 /* Expose While NOT External Trigger is low */
#define OP_FLASH             23 /* Turn the FLASH LED on for (N) milliseconds */
/******************************************************************************
        The names of the DSP56001 programs using the above interface.
******************************************************************************/
extern unsigned char far dsp_cam200k[];
extern int size_of_dsp_cam200k;
extern unsigned char far dsp_cam216[];
extern int size_of_dsp_cam216;
extern unsigned char far dsp_cam40k[];
extern int size_of_dsp_cam40k;
extern unsigned char far dsp_cam500k[];
extern int size_of_dsp_cam500k;
extern unsigned char far dsp_cam50k[];
extern int size_of_dsp_cam50k;
