/******************************************************************************
        Write a subroutine to select only one specific CCD every time.
******************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <at200.h>
#include <at200oem.h>

void show_help(void)
{ /* Display the usage message for this program */
register x;
char buff[81],number[8];

  printf("USAGE: MYCAMERA [-a #] -c # [-d #] [-f] [-o #] [-p #] -s #\n"
         "  Where:\n"
         "    -a #  # is the base address descriptor (2 by default)\n"
         "    -c #  # selects the CCD type from the following list:\n");
  strcpy(buff,"           ");
  for( x=0 ; x<CCD_COUNT ; x++ ) {
    sprintf(number," %u=",x);
    if( strlen(buff) + strlen(number) + strlen(ccd[x].id) < 80 ) {
      strcat(buff,number);
      strcat(buff,ccd[x].id);
    }
    else {
      printf("%s\n",buff);
      strcpy(buff,"           ");
      strcat(buff,number);
      strcat(buff,ccd[x].id);
    }
  }
  printf("%s\n",buff);
  printf("    -d #  # is the number of data bits (12 or 14) for 200 KHz only\n"
         "    -f    indicates a frame transfer CCD\n"
         "    -o #  # is the open/close time for the shutter in milliseconds (>=0)\n"
         "    -p #  # is the setteling time for the preamp in milliseconds (>=0)\n"
         "    -s #  # selects the A/D Converter speed where:\n"
         "            0=40 KHz, 1=50 KHz, 2=200 KHz, 3=500 KHz\n");
  exit( 1 );
}

void main(int argc,char *argv[])
{
int x;
int ccd_type  = -1,   /* Required parameter */
    speed     = -1,   /* Required parameter */
    data_bits = -1,   /* Required parameter for 200 KHz only */
    at200_id  = 2,    /* Address 0x220 */
    frame     = 0,    /* Not frame transfer */
    preamp    = 100,  /* Normal preamp delay */
    shutter   = 31;   /* Ilex 1" shutter */

  for( x=1 ; x < argc ; x++ ) {
    if( argv[x][0] == '-' )
      switch( argv[x][1] ) {
        case 'a': case 'A':
          x++;
          at200_id = atoi(argv[x]);
          break;
        case 'c': case 'C':
          x++;
          ccd_type = atoi(argv[x]);
          break;
        case 'd': case 'D':
          x++;
          data_bits = atoi(argv[x]);
          break;
        case 'f': case 'F':
          frame = 1;
          break;
        case 'o': case 'O':
          x++;
          shutter = atoi(argv[x]);
          break;
        case 'p': case 'P':
          x++;
          preamp = atoi(argv[x]);
          break;
        case 's': case 'S':
          x++;
          speed = atoi(argv[x]);
          break;
        default:
          show_help();
          break;
      }
    else
      show_help();
  }
  if( at200_id < 0 || at200_id > 31 )
    show_help();
  if( ccd_type < 0 || ccd_type >= CCD_COUNT )
    show_help();
  if( frame && !ccd[ccd_type].frame_transfer ) {
    printf("The CCD you selected is not frame transfer capable.\n");
    exit( 1 );
  }
  if( shutter < 0 )
    show_help();
  if( preamp < 0 )
    show_help();
  switch( speed ) {
    case A40KHZ:
      data_bits = 16;
      break;
    case A50KHZ:
      data_bits = 14;
      break;
    case A200KHZ:
      if( data_bits != 12 && data_bits != 14 )
        show_help();
      break;
    case A500KHZ:
      data_bits = 12;
      break;
    default:
      show_help();
      break;
  }
  /********************* Write a subroutine to stdout ***********************/
  printf("#include <at200.h>\n"
         "#include <at200oem.h>\n"
         "\n"
         "int setup_my_camera(void) /* Set up the CCD characterization */\n"
         "{\n"
         "static cam_sys config = { { %u,%u,%u,%u,%u,%u,%u,%u,%u,%u,\"%s\" },\n"
         "                          %u,%u,%u,%u,%u,%u,%u };\n"
         "\n"
         "  return( setup(&config) );\n"
         "}\n",
         ccd[ccd_type].cols,ccd[ccd_type].rows,ccd[ccd_type].prescan,
         ccd[ccd_type].postscan,ccd[ccd_type].parallel_delay,
         ccd[ccd_type].parallel_states,ccd[ccd_type].frame_transfer,
         ccd[ccd_type].mpp_expose,ccd[ccd_type].mpp_clock,
         ccd[ccd_type].high_hwell,ccd[ccd_type].id,
         at200_id,frame,shutter,shutter,preamp,speed,data_bits);
  exit( 0 );
}
